@@ -52,7 +52,7 @@ EVT_CHECKBOX(SHOW_PLAYERS_ONLY_CHECK, ChatPanel::OnShowPlayerOnlyCheck)
 END_EVENT_TABLE()
 
 
-SLCONFIG("/Channel/bridgebot", (const wxString&) _T("TIZBOT"), "Name of the Bridgebot (which forwards traffic between #sy and irc channels)");
+SLCONFIG("/Channel/bridgebot", (const wxString&)_T("TIZBOT"), "Name of the Bridgebot (which forwards traffic between #sy and irc channels)");
 SLCONFIG("/GUI/ShowPromotions", true, "Show promotion messages as popup");
 
 /// table for irc colors
@@ -784,15 +784,10 @@ void ChatPanel::Parted(User& who, const wxString& message)
 
 void ChatPanel::SetTopic(const wxString& who, const wxString& message)
 {
-	/*
-	int pos = refined.Find( _T("\\n") ); // serch for the \n string
-	while ( pos != -1 )
-	{
-	if ( refined.Mid( pos - 1, 3 ) == _T("\\\n") ) continue; // the string \\n means escaped \n
-	refined = refined.Left ( pos -1 ) + _T("\n") + refined.Right( pos +1 ); // replace the /n string with the carriage return char
-	pos = refined.Find( _T("\\n") );
+	if (message.empty()) {
+		m_topic_set = false;
+		return;
 	}
-	*/
 	const wxColor col = sett().GetChatColorServer();
 	// change the image of the tab to show new events
 	if (m_topic_set)
@@ -1016,17 +1011,6 @@ bool ChatPanel::Say(const wxString& message) //FIXME: remove all parsing / token
 				return true;
 			}
 
-			//we need to disable the channel tab if leaving manually
-			if (line.Upper().StartsWith(_T( "LEAVE" ))) {
-				wxString channame = line.AfterFirst(' ').BeforeFirst(' ');
-				try {
-					Channel& chan = m_server->GetChannel(STD_STRING(channame));
-					chan.Leave();
-					chan.panel = 0;
-				} catch (assert_exception) {
-				}
-			}
-
 			m_server->SendCmd(STD_STRING(line), "");
 			OutputLine(_("Sent: \"") + line + _T("\""), sett().GetChatColorNormal());
 		}
