@@ -5,10 +5,11 @@
 
 #include <wx/scrolwin.h>
 #include <vector>
-
+#include "gui/controls.h"
 class Ui;
 class MapCtrl;
 class BattleroomListCtrl;
+class wxCheckBox;
 class wxCommandEvent;
 class wxDataViewEvent;
 class wxStaticText;
@@ -17,7 +18,6 @@ class wxButton;
 class wxBoxSizer;
 class wxStaticText;
 class wxStaticLine;
-class wxCheckBox;
 class wxToggleButton;
 struct StoredGame;
 class PlaybackLoader;
@@ -37,7 +37,7 @@ public:
 	~PlaybackTab();
 
 	//! adds a single replay to listctrl
-	void AddPlayback(const StoredGame& Replay);
+	void AddPlayback(const StoredGame& Replay, bool resortIsNeeded = true);
 	void RemovePlayback(const StoredGame& Replay);
 	void UpdatePlayback(const StoredGame& Replay);
 
@@ -76,10 +76,12 @@ private:
 	PlaybackDataView* m_replay_dataview;
 	PlaybackLoader* m_replay_loader;
 	MapCtrl* m_minimap;
+	wxStaticText* m_engine_lbl;
+	wxStaticText* m_engine_text;
 	wxStaticText* m_map_lbl;
 	wxStaticText* m_map_text;
-	wxStaticText* m_mod_lbl;
-	wxStaticText* m_mod_text;
+	wxStaticText* m_game_lbl;
+	wxStaticText* m_game_text;
 	wxStaticText* m_players_lbl;
 	wxStaticText* m_players_text;
 
@@ -92,11 +94,7 @@ private:
 
 	wxCheckBox* m_filter_activ;
 	bool m_isreplay;
-#if wxUSE_TOGGLEBTN
-	wxToggleButton* m_filter_show;
-#else
-	wxCheckBox* m_filter_show;
-#endif
+	wxToggleOrCheck* m_filter_show;
 
 	void AskForceWatch(StoredGame& rep) const;
 
