@@ -1,31 +1,26 @@
 /* This file is part of the Springlobby (GPL v2 or later), see COPYING */
-
-
 #include "tab_abstract.h"
-#include <wx/string.h>
-#include <wx/gbsizer.h>
-#include <wx/event.h>
-#include <wx/defs.h>
-#include <wx/slider.h>
-#include <wx/log.h>
-#include <wx/checkbox.h>
-#include <wx/radiobut.h>
-#include <wx/combobox.h>
-#include <wx/textctrl.h>
-#include <wx/display.h>
-#include <wx/spinctrl.h>
-
-
-#include "gui/customdialogs.h"
-#include "utils/conversion.h"
-#include "ctrlconstants.h"
-#include "settings.h"
-#include "presets.h"
-
-#include "log.h"
 
 #include <lslunitsync/unitsync.h>
+#include <wx/checkbox.h>
+#include <wx/combobox.h>
+#include <wx/defs.h>
+#include <wx/display.h>
+#include <wx/event.h>
+#include <wx/gbsizer.h>
+#include <wx/log.h>
+#include <wx/radiobut.h>
+#include <wx/slider.h>
+#include <wx/spinctrl.h>
+#include <wx/string.h>
+#include <wx/textctrl.h>
 
+#include "ctrlconstants.h"
+#include "gui/customdialogs.h"
+#include "log.h"
+#include "presets.h"
+#include "settings.h"
+#include "utils/conversion.h"
 
 intMap abstract_panel::intSettings;
 stringMap abstract_panel::stringSettings;
@@ -193,7 +188,8 @@ void abstract_panel::loadDefaults()
 	for (int i = 0; i < s_category_sizes[_T("W4_CONTROLS")] - 1; ++i)
 		intSettings[W4_CONTROLS[i].key] = FromwxString(W4_CONTROLS[i].def);
 
-	floatSettings[W4_CONTROLS[s_category_sizes[_T("W4_CONTROLS")]].key] = FromwxString(W4_CONTROLS[s_category_sizes[_T("W4_CONTROLS")]].def);
+	const size_t idx = s_category_sizes[_T("W4_CONTROLS")] - 1;
+	floatSettings[W4_CONTROLS[idx].key] = FromwxString(W4_CONTROLS[idx].def); //TODO add comment: what does this do?
 }
 
 void abstract_panel::OnSliderMove(wxCommandEvent& event)
@@ -206,7 +202,7 @@ void abstract_panel::OnSliderMove(wxCommandEvent& event)
 	int value = slider->GetValue();
 	int id = event.GetId();
 
-	switch (event.GetId()) {
+	switch (id) {
 		case ID_RO_SLI_0: {
 			// shadow-map sizes
 			int val = slider->GetValue();
@@ -283,7 +279,7 @@ void abstract_panel::OnSliderMove(wxCommandEvent& event)
 			(intSettings)[MO_SLI_EXT[4].key] = (value > 0 ? 1 : 0);
 		} break;
 		default:
-			slLogDebugFunc("unhandled case val");
+			wxLogWarning(_T("Unhandled switch case: %d"), id);
 			break;
 	}
 }
@@ -314,7 +310,7 @@ void abstract_panel::OnTextUpdate(wxCommandEvent& event)
 			} break;
 
 			default:
-				slLogDebugFunc("unhandled case val");
+				wxLogWarning(_T("Unhandled switch case: %d"), eventID);
 				break;
 		}
 	}
@@ -399,7 +395,7 @@ void abstract_panel::OnCheckBoxTick(wxCommandEvent& event)
 		} break;
 
 		default:
-			slLogDebugFunc("unhandled case val");
+			wxLogWarning(_T("Unhandled switch case: %d"), id);
 			break;
 	}
 }
@@ -438,7 +434,7 @@ void abstract_panel::OnRadioButtonToggle(wxCommandEvent& event)
 		} break; // FC button (CamMode 4)
 
 		default:
-			slLogDebugFunc("unhandled case val");
+			wxLogWarning(_T("Unhandled switch case: %d"), event.GetId());
 			break;
 	}
 }
@@ -476,7 +472,7 @@ void abstract_panel::OnComboBoxChange(wxCommandEvent& event)
 				} break; // BumpWater
 
 				default:
-					slLogDebugFunc("unhandled case val");
+					wxLogWarning(_T("Unhandled switch case: %d"), choiceIndex);
 					break;
 			}
 			break;
@@ -560,9 +556,8 @@ void abstract_panel::OnComboBoxChange(wxCommandEvent& event)
 			}
 			break;
 		}
-
 		default:
-			slLogDebugFunc("unhandled case val");
+			wxLogWarning(_T("Unhandled switch case: %d"), event.GetId());
 			break;
 	}
 }
