@@ -11,6 +11,7 @@ lsl/networking/tasserver.cpp
 **/
 #include "tasserver.h"
 
+#include <lslunitsync/unitsync.h>
 #include <json/reader.h>
 #include <lslutils/misc.h>
 #include <wx/intl.h>
@@ -366,6 +367,11 @@ const User& TASServer::GetMe() const
 	return GetUser(GetUserName());
 }
 
+const std::string TASServer::GetSys()
+{
+	return LSL::usync().GetSys().substr(0,16);
+}
+
 void TASServer::Login()
 {
 	slLogDebugFunc("");
@@ -377,9 +383,9 @@ void TASServer::Login()
 	if (localaddr.empty())
 		localaddr = "*";
 	m_id_transmission = false;
-	SendCmd("LOGIN", stdprintf("%s %s 0 %s %s\t%u\ta m sp cl p",
-	  GetUserName().c_str(), pass.c_str(), localaddr.c_str(),
-	  GetSpringlobbyAgent().c_str(), m_crc.GetCRC()));
+	SendCmd("LOGIN", stdprintf("%s %s 0 %s %s\t%u %s\tsp cl u l t",
+	GetUserName().c_str(), pass.c_str(), localaddr.c_str(),
+	GetSpringlobbyAgent().c_str(), m_crc.GetCRC(), GetSys().c_str()));
 	m_id_transmission = true;
 }
 
@@ -395,9 +401,9 @@ void TASServer::RequestChannels()
 }
 
 
-void TASServer::AcceptAgreement()
+void TASServer::AcceptAgreement(const std::string& verif_code)
 {
-	SendCmd("CONFIRMAGREEMENT");
+	SendCmd("CONFIRMAGREEMENT " + verif_code);
 }
 
 
@@ -523,7 +529,7 @@ static LSL::StringMap parseKeyValue(const std::string& str)
 void TASServer::ExecuteCommand(const std::string& cmd, const std::string& inparams, int replyid)
 {
 	std::string params = inparams;
-	std::string nick, contry, host, map, title, channel, error, msg, owner, topic, engineName, engineVersion;
+	std::string nick, host, map, title, channel, bridge, error, msg, owner, topic, engineName, engineVersion;
 	//NatType ntype;
 	UserStatus cstatus;
 	int tasstatus;
@@ -543,7 +549,7 @@ void TASServer::ExecuteCommand(const std::string& cmd, const std::string& inpara
 			m_server_lanmode = GetBoolParam(params);
 
 			if (m_do_register) {
-				SendCmd("REGISTER", m_serverinfo.username + std::string(" ") + GetPasswordHash(m_serverinfo.password));
+				SendCmd("REGISTER", m_serverinfo.username + std::string(" ") + GetPasswordHash(m_serverinfo.password) + std::string(" ") + m_serverinfo.email);
 			} else {
 				m_se->OnConnected(m_serverinfo.description, "", true, m_supported_spring_version, m_server_lanmode);
 			}
@@ -554,7 +560,7 @@ void TASServer::ExecuteCommand(const std::string& cmd, const std::string& inpara
 		if (!m_sock->IsTLS()) {
 			wxLogInfo("%s:%d %s", m_serverinfo.hostname.c_str(), m_serverinfo.port, m_serverinfo.fingerprint.c_str());
 			m_sock->StartTLS(m_serverinfo.fingerprint);
-			Start(); //restart ping as server + client have startet TLS
+			Start(); //restart ping as server + client have started TLS
 		}
 	} else if (cmd == "ACCEPTED") {
 		SetUsername(params);
@@ -564,8 +570,7 @@ void TASServer::ExecuteCommand(const std::string& cmd, const std::string& inpara
 	} else if (cmd == "ADDUSER") {
 		int id;
 		nick = GetWordParam(params);
-		contry = GetWordParam(params);
-		const int cpu = GetIntParam(params);
+		const std::string country = GetWordParam(params);
 		if (params.empty()) {
 			// if server didn't send any account id to us, fill with an always increasing number
 			id = m_account_id_count;
@@ -573,7 +578,8 @@ void TASServer::ExecuteCommand(const std::string& cmd, const std::string& inpara
 		} else {
 			id = GetIntParam(params);
 		}
-		m_se->OnNewUser(nick, contry, cpu, id);
+		// params contains user's lobby client and version.
+		m_se->OnNewUser(nick, country, id, params);
 		if (nick == m_relay_host_bot) {
 			RelayCmd("OPENBATTLE", m_delayed_open_command); // relay bot is deployed, send host command
 			m_delayed_open_command = "";
@@ -599,8 +605,9 @@ void TASServer::ExecuteCommand(const std::string& cmd, const std::string& inpara
 		map = GetSentenceParam(params);
 		title = GetSentenceParam(params);
 		const std::string mod = GetSentenceParam(params);
+		const std::string channel_name = GetSentenceParam(params);
 		m_se->OnBattleOpened(id, (BattleType)type, IntToNatType(nat), nick, host, port, maxplayers,
-				     haspass, rank, hash, engineName, engineVersion, map, title, mod);
+				     haspass, rank, hash, engineName, engineVersion, map, title, mod, channel_name);
 		if (nick == m_relay_host_bot) {
 			GetBattle(id).SetProxy(m_relay_host_bot);
 			JoinBattle(id, STD_STRING(sett().GetLastHostPassword())); // autojoin relayed host battles
@@ -667,9 +674,8 @@ void TASServer::ExecuteCommand(const std::string& cmd, const std::string& inpara
 	} else if (cmd == "CHANNELTOPIC") {
 		channel = GetWordParam(params);
 		nick = GetWordParam(params);
-		int pos = GetIntParam(params);
 		params = LSL::Util::Replace(params, "\\n", "\n");
-		m_se->OnChannelTopic(channel, nick, params, pos / 1000);
+		m_se->OnChannelTopic(channel, nick, params);
 	} else if (cmd == "SAIDEX") {
 		channel = GetWordParam(params);
 		nick = GetWordParam(params);
@@ -795,12 +801,6 @@ void TASServer::ExecuteCommand(const std::string& cmd, const std::string& inpara
 		//Cmd: ENDOFCHANNELS params:
 	} else if (cmd == "REQUESTBATTLESTATUS") {
 		m_se->OnRequestBattleStatus(m_battle_id);
-	} else if (cmd == "SAIDBATTLE") {
-		nick = GetWordParam(params);
-		m_se->OnSaidBattle(m_battle_id, nick, params);
-	} else if (cmd == "SAIDBATTLEEX") {
-		nick = GetWordParam(params);
-		m_se->OnBattleAction(m_battle_id, nick, params);
 	} else if (cmd == "AGREEMENT") {
 		msg = GetSentenceParam(params);
 		m_agreement += msg + "\n";
@@ -957,8 +957,39 @@ void TASServer::ExecuteCommand(const std::string& cmd, const std::string& inpara
 		m_se->OnConnected(m_serverinfo.description, "", true, m_supported_spring_version, m_server_lanmode);
 	} else if (cmd == "REGISTRATIONDENIED") {
 		m_se->RegistrationDenied(params);
+	} else if (cmd == "JOINEDFROM") {
+		channel = GetWordParam(params);
+		bridge = GetWordParam(params);
+		nick = GetWordParam(params);
+		if (!UserExists(nick)) // bridged users are only known when in a channel with them
+		{
+			const int id = m_account_id_count;
+			m_account_id_count++;
+			m_se->OnNewUser(nick, "", id, bridge + " (bridge)");
+		}
+		m_se->OnJoinedFrom(channel, nick);
+	} else if (cmd == "CLIENTSFROM") {
+		channel = GetWordParam(params);
+		bridge = GetWordParam(params);
+		while (!(nick = GetWordParam(params)).empty()) {
+			if (!UserExists(nick)) {
+				const int id = m_account_id_count;
+				m_account_id_count++;
+				m_se->OnNewUser(nick, "", id, bridge + " (bridge)");
+			}
+			m_se->OnJoinedFrom(channel, nick);
+		}
+	} else if (cmd == "LEFTFROM") {
+		channel = GetWordParam(params);
+		nick = GetWordParam(params);
+		m_se->OnLeftFrom(channel, nick);
+	} else if (cmd == "SAIDFROM") {
+		channel = GetWordParam(params);
+		nick = GetWordParam(params);
+		msg = GetSentenceParam(params);
+		m_se->OnSaidFrom(channel, nick, msg);
 	} else {
-		wxLogWarning(wxString::Format("??? Cmd: %s params: %s" , cmd.c_str(), params.c_str()));
+		wxLogWarning(wxString::Format("??? Cmd: %s params: %s", cmd.c_str(), params.c_str()));
 		m_se->OnUnknownCommand(cmd, params);
 	}
 }
@@ -967,9 +998,9 @@ void TASServer::ParseJson(const std::string& jsonstr)
 {
 	wxLogDebug("JSON %s", jsonstr.c_str());
 
-        Json::Value js; // will contains the root value after parsing.
-        Json::Reader reader;
-        const bool parsingSuccessful = reader.parse(jsonstr, js);
+	Json::Value js; // will contains the root value after parsing.
+	Json::Reader reader;
+	const bool parsingSuccessful = reader.parse(jsonstr, js);
 	if (!parsingSuccessful) {
 		wxLogWarning("Invalid json: %s", jsonstr.c_str());
 		return;
@@ -1032,15 +1063,24 @@ void TASServer::SendCmd(const std::string& command, const std::string& param, bo
 		return;
 	}
 
-	if (command == "PING") return;
-	if (command == "SAY") return;
-	if (command == "SAYEX") return;
-	if (command == "SAYPRIVATE") return;
-	if (command == "SAYPRIVATEEX") return;
-	if (command == "SAYBATTLE") return;
-	if (command == "SAYBATTLEEX") return;
-	if (command == "SAYBATTLEPRIVATE") return;
-	if (command == "SAYBATTLEPRIVATEEX") return;
+	if (command == "PING")
+		return;
+	if (command == "SAY")
+		return;
+	if (command == "SAYEX")
+		return;
+	if (command == "SAYPRIVATE")
+		return;
+	if (command == "SAYPRIVATEEX")
+		return;
+	if (command == "SAYBATTLE")
+		return;
+	if (command == "SAYBATTLEEX")
+		return;
+	if (command == "SAYBATTLEPRIVATE")
+		return;
+	if (command == "SAYBATTLEPRIVATEEX")
+		return;
 
 	if (send_success)
 		wxLogMessage(wxString::Format(_T("sent: %s"), msg.c_str()));
@@ -1265,10 +1305,8 @@ void TASServer::HostBattle(const BattleOptions& bo, const std::string& password)
 	cmd += LSL::Util::MakeHashSigned(bo.gamehash);
 	cmd += stdprintf(" %d ", bo.rankneeded);
 	cmd += LSL::Util::MakeHashSigned(bo.maphash) + std::string(" ");
-	if (!bo.userelayhost) { //FIXME: relay host hasn't multiversion support yet, see https://github.com/springlobby/springlobby/issues/98
-		cmd += bo.engineName + std::string("\t");
-		cmd += bo.engineVersion + std::string("\t");
-	}
+	cmd += bo.engineName + std::string("\t");
+	cmd += bo.engineVersion + std::string("\t");
 	cmd += bo.mapname + std::string("\t");
 	cmd += LSL::Util::Replace(bo.description, "\t", "    ") + std::string("\t");
 	cmd += bo.gamename;
@@ -1368,7 +1406,7 @@ void TASServer::FinalizeJoinBattle()
 }
 
 
-void TASServer::LeaveBattle(const int& /*unused*/)
+void TASServer::LeaveBattle(const int& /*battle_id*/)
 {
 	//LEAVEBATTLE
 	slLogDebugFunc("");
@@ -1910,8 +1948,7 @@ void TASServer::UdpPingTheServer(const std::string& message)
 
 
 // copypasta from spring.cpp , to get users ordered same way as in tasclient.
-struct UserOrder
-{
+struct UserOrder {
 	int index; // user number for GetUser
 	int order; // user order (we'll sort by it)
 	bool operator<(UserOrder b) const
@@ -2080,4 +2117,3 @@ void TASServer::OnInvalidFingerprintReceived(const std::string& fingerprint, con
 {
 	m_se->OnInvalidFingerprintReceived(fingerprint, expected_fingerprint);
 }
-
